Internal palette used as a default when a number of phases or subgroups need distinct colours. For most plots, ggplot2's default palette is fine; this is provided for backward compatibility and quick prototyping.
Internal palette used as a default when a number of phases or subgroups need distinct colours. For most plots, ggplot2's default palette is fine; this is provided for backward compatibility and quick prototyping.